@@ -9,7 +9,6 @@ import asyncio
 from ai_kit.cli.registry import registry_instance
 from ai_kit import __version__  # Import version
 from ai_kit.shared_console import shared_console, shared_error_console
-from ai_kit.cli.commands.gitingest import gitingest_command
 
 # Configure basic logging
 logging.basicConfig(
@@ -287,7 +286,29 @@ def gitingest(repo: str, output_dir: str):
     - content.md: Repository content with markdown formatting
     - digest.txt: Complete digest in plain text
     """
+    from ai_kit.cli.commands.gitingest import gitingest_command
     asyncio.run(gitingest_command(
         repo=repo,
         output_dir=output_dir,
-    )) 
\ No newline at end of file
+    )) 
+
+@main.group(name="teammate")
+def teammate():
+    """Work with specialized AI teammates that complement Claude's capabilities."""
+    pass
+
+@teammate.command(name="clyde")
+@click.argument("query")
+@registry_instance.add(
+    name="teammate clyde",
+    description="Interact with Clyde, a test implementation using Anthropic's Claude 3.7 Sonnet model.",
+    usage="ai-kit teammate clyde <query>",
+)
+def teammate_clyde(query: str):
+    """Interact with Clyde, a test implementation using Anthropic's API."""
+    from ai_kit.cli.teammates.clyde import clyde_command
+    try:
+        asyncio.run(clyde_command(query))
+    except Exception as e:
+        shared_error_console.print(f"[bold red]Error in Clyde teammate:[/] {str(e)}")
+        sys.exit(1) 
\ No newline at end of file
